==> octave-8.3.0.tar.xz: octave-8.3.0/libgui/graphics/PushTool.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2011-2023 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if ! defined (octave_PushTool_h)
#define octave_PushTool_h 1

#include "ToolBarButton.h"

OCTAVE_BEGIN_NAMESPACE(octave)

class base_qobject;
class interpreter;

class PushTool : public ToolBarButton<uipushtool>
{
  Q_OBJECT

public:
  PushTool (octave::base_qobject& oct_qobj, octave::interpreter& interp,
            const graphics_object& go, QAction *action);
  ~PushTool (void);

  static PushTool *
  create (octave::base_qobject& oct_qobj, octave::interpreter& interp,
          const graphics_object& go);

protected:
  void update (int pId);

private slots:
  void clicked (void);
};

OCTAVE_END_NAMESPACE(octave)

#endif

==> octave_10.3.0.orig.tar.xz: octave-10.3.0/libgui/graphics/PushTool.h <==
////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2011-2025 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if ! defined (octave_PushTool_h)
#define octave_PushTool_h 1

#include "ToolBarButton.h"

OCTAVE_BEGIN_NAMESPACE(octave)

class interpreter;

class PushTool : public ToolBarButton<uipushtool>
{
  Q_OBJECT

public:
  PushTool (octave::interpreter& interp,
            const graphics_object& go, QAction *action);
  ~PushTool ();

  static PushTool *
  create (octave::interpreter& interp,
          const graphics_object& go);

protected:
  void update (int pId);

private Q_SLOTS:
  void clicked ();
};

OCTAVE_END_NAMESPACE(octave)

#endif
